!-----------------------------------------------------------------------------
!
! Read in, tabulate, and interpolate a function, and find an inverse; i.e.,
! given a function of x, f=f(x), we find a value of x for a given value of f.
!
! [1st column] x
! [2nd column] f(x)
!
! May 18, 2016
! E. Komatsu
!
!-----------------------------------------------------------------------------
MODULE Fx
  IMPLICIT none
  INTEGER :: jlo,ndata
  DOUBLE PRECISION, dimension(:), allocatable :: xa,ya,y2a
contains
  SUBROUTINE Open_File(filename,n)
    IMPLICIT none
    DOUBLE PRECISION, dimension(:), allocatable :: x,f
    CHARACTER(len=128) :: filename
    INTEGER, intent(IN) :: n
    INTEGER :: i
    ndata=n
    ALLOCATE(xa(ndata),ya(ndata),y2a(ndata))
    ALLOCATE(x(ndata),f(ndata))
    open(1,file=filename,status='old',form='formatted')
    print*,'read in '//trim(filename)
    do i=1,ndata
       read(1,*)x(i),f(i)
    enddo
    close(1)
    xa=f
    ya=x
    DEALLOCATE(x,f)
    CALL spline(xa,ya,ndata,1.d30,1.d30,y2a)
    return
  END SUBROUTINE Open_File
  SUBROUTINE Close_File
    DEALLOCATE(xa,ya,y2a)
    return
  END SUBROUTINE Close_File
END MODULE Fx
DOUBLE PRECISION FUNCTION Find_x(f)
  Use Fx
  IMPLICIT none
  DOUBLE PRECISION :: a,b,h,x,y,f
  x  = f
  CALL hunt(xa,ndata,x,jlo)
  h=xa(jlo+1)-xa(jlo)
  a=(xa(jlo+1)-x)/h
  b=(x-xa(jlo))/h
  y=a*ya(jlo)+b*ya(jlo+1)+((a**3-a)*y2a(jlo)+(b**3-b)*y2a(jlo+1))*(h**2)/6.
  Find_x = y
  return
END FUNCTION Find_x
